@@ -266,7 +266,7 @@ use strict;
 use warnings;
 use utf8;
 use parent qw/Amon2/;
-our $VERSION='3.85';
+our $VERSION='3.86';
 use 5.008001;
 
 __PACKAGE__->load_plugin(qw/DBI/);
@@ -345,18 +345,53 @@ done_testing;
 
     $self->write_file("xt/02_perlcritic.t", <<'...');
 use strict;
+use warnings;
 use Test::More;
-eval q{
-    use Perl::Critic 1.113;
-    use Test::Perl::Critic 1.02 -exclude => [
-        'Subroutines::ProhibitSubroutinePrototypes',
-        'Subroutines::ProhibitExplicitReturnUndef',
-        'TestingAndDebugging::ProhibitNoStrict',
-        'ControlStructures::ProhibitMutatingListFunctions',
-    ];
+
+eval {
+    require Perl::Critic;
+    Perl::Critic->VERSION(1.105);
+
+    require Test::Perl::Critic;
+    Test::Perl::Critic->VERSION(1.02);
+    Test::Perl::Critic->import(
+        -profile => \(join q{}, <DATA>)
+    );
 };
-plan skip_all => "Test::Perl::Critic 1.02+ and Perl::Critic 1.113+ is not installed." if $@;
-all_critic_ok('lib');
+note $@ if $@;
+plan skip_all => "Perl::Critic 1.105+ or Test::Perl::Critic 1.02+ is not installed." if $@;
+
+all_critic_ok('lib', 'script', 'bin');
+
+__END__
+
+only=1
+
+# -------------------------------------------------------------------------
+# Not important.
+
+[BuiltinFunctions::ProhibitSleepViaSelect]
+[BuiltinFunctions::RequireGlobFunction]
+[ClassHierarchies::ProhibitOneArgBless]
+
+# -------------------------------------------------------------------------
+# Bug detection
+[InputOutput::ProhibitBarewordFileHandles]
+[Modules::RequireFilenameMatchesPackage]
+[Subroutines::ProhibitNestedSubs]
+[Subroutines::ProhibitReturnSort]
+[TestingAndDebugging::RequireUseStrict]
+[Variables::ProhibitConditionalDeclarations]
+[Variables::RequireLexicalLoopIterators]
+
+[TestingAndDebugging::ProhibitNoStrict]
+allow=refs
+
+# -------------------------------------------------------------------------
+# Security issue detection
+[InputOutput::RequireEncodingWithUTF8Layer]
+[Modules::ProhibitEvilModules]
+[InputOutput::ProhibitTwoArgOpen]
 ...
 
     $self->write_file('.gitignore', <<'...');
@@ -419,7 +454,7 @@ use Test::Requires 'Text::SimpleTable';
 use File::Basename;
 
 plan skip_all => 'this test requires "jshint" command'
-  unless `jshint --version` =~ /\d/;
+  if system("jshint --version") != 0;
 
 my @files = (<static/*/*.js>, <static/*/*/*.js>, <static/*/*/*/*.js>);
 
